@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
-import useful.main
+import useful
 
 useful.main.handle()
\ No newline at end of file
